@@ -2,7 +2,7 @@ context("geom_vridgeline")
 
 
 # Visual tests ------------------------------------------------------------
-test_that("visual appearance", {
+test_that("visual appearance of geom_vridgeline", {
   d <- data.frame(y = rep(1:5, 3), x = c(rep(0, 5), rep(1, 5), rep(3, 5)),
                   width = c(0, 1, 3, 4, 0, 1, 2, 3, 5, 4, 0, 5, 4, 4, 1))
   p <- ggplot(d, aes(x, y, width = width, group = x)) + geom_vridgeline(fill="lightblue")
